Module kseq::record[][src]

Structs

a structure representing the sequence in a fastx file

a Reader with shared buffer

multiple readers for a fofn file

Enums

The type of error that returned during parsing fastx files

Type Definitions