Struct kseq::record::Fastx [−][src]
pub struct Fastx<'a> { /* fields omitted */ }Expand description
a structure representing the sequence in a fastx file
pub struct Fastx<'a> { /* fields omitted */ }a structure representing the sequence in a fastx file